# LRGASP Guidelines and Tools

Documentation and software for submitting to the
Long Read Genome Annotation Assessment Project (LRGASP).

Current documentation is publish at [LRGASP Guidelines and Tools](https://lrgasp.github.io/lrgasp-submissions/docs).

Synapse challenge is at [Synapse LRGASP](https://www.synapse.org/#!Synapse:syn25007472/wiki/608702)

Github repository is at [LRGASP/lrgasp-submissions](https://github.com/LRGASP/lrgasp-submissions).


